==> fap_0.8.8.orig.tar.bz2: fap-0.8.8/src/translator.cpp <==
/*
 *  Copyright (C) 2010 Leandro Nini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include "translator.h"

#include "gettext.h"
#include <locale.h>

#ifdef _WIN32
#  include <windows.h>
#endif

FXIMPLEMENT(translator, FXTranslator, 0, 0)

translator::translator(FXApp *a) : FXTranslator(a) {

	char* locale=setlocale(LC_ALL, "");
	FXTRACE((10, "locale: %s\n", locale));
#ifndef _WIN32
	bindtextdomain(PACKAGE, LOCALEDIR);
#else
	FXString cmd=FXPath::directory(FXPath::dequote(GetCommandLine())).append("\\locale");
	bindtextdomain(PACKAGE, cmd.text());
	FXTRACE((10, "localedir: %s\n", cmd.text()));
#endif

	textdomain(PACKAGE);
}

translator::~translator() {};

const FXchar* translator::tr(const FXchar *context, const FXchar *message, const FXchar *hint) const {

	return gettext(message);
}

==> fap-0.9.2.tar.bz2: fap-0.9.2/src/translator.cpp <==
/*
 *  Copyright (C) 2010 Leandro Nini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include "translator.h"

#include "gettext.h"
#include <locale.h>

#ifdef _WIN32
#  include <windows.h>
#endif

FXIMPLEMENT(translator, FXTranslator, 0, 0)

translator::translator(FXApp *a) : FXTranslator(a) {

	char* locale=setlocale(LC_ALL, "");
	FXTRACE((10, "locale: %s\n", locale));
#ifndef _WIN32
	bindtextdomain(PACKAGE, LOCALEDIR);
#else
	FXString cmd=FXPath::directory(FXPath::dequote(GetCommandLine())).append("\\locale");
	bindtextdomain(PACKAGE, cmd.text());
	FXTRACE((10, "localedir: %s\n", cmd.text()));
#endif

	textdomain(PACKAGE);
}

translator::~translator() {}

const FXchar* translator::tr(const FXchar *context, const FXchar *message, const FXchar *hint) const {

	return gettext(message);
}
